use std::fmt::Display;

#[derive(thiserror::Error, Debug)]
pub struct Error {
    message: String,
    #[source]
    source: anyhow::Error,
}

impl Display for Error {
    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
        write!(f, "error: {} ", self.message).and_then(|_| self.source.fmt(f))
    }
}

impl From<anyhow::Error> for Error {
    fn from(value: anyhow::Error) -> Self {
        Self {
            message: value.to_string(),
            source: value,
        }
    }
}

impl From<std::io::Error> for Error {
    fn from(value: std::io::Error) -> Self {
        Self{
            message: value.to_string(),
            source: anyhow::Error::from(value)
        }
    }
}

